/*
 *  Quick Test: CLI for stress testing in competitive programming
 *  Copyright (C) 2021 - Luis Miguel Báez
 *  License: MIT (See the LICENSE file in the repository root directory)
 */

mod tle_subcommand;
mod cmp_subcommand;
mod check_subcommand;
mod test_utilities;
mod test_constants;